@@ -172,33 +172,30 @@ densiTree <- function(x, type = "cladogram", alpha = 1 / length(x),
   xy <- plotPhyloCoor(consensus, direction = direction, ...)
   yy <- xy[, 2]
 
-  plot.new()
   tl <- which.max(nchar(consensus$tip.label))
-  sw <- strwidth(consensus$tip.label[tl], cex = cex) * 1.1
+  if(horizontal) pin1 <- par("pin")[1]
+  else pin1 <- par("pin")[2]
+  sw <- strwidth(consensus$tip.label[tl], "inch", cex = cex) / pin1  * 1.1
 
   if (direction == "rightwards") {
-#    plot.window(xlim = c(0, 1.0 + sw), ylim = c(0, nTip + 1))
     plot.default(0, type = "n", xlim = c(0, 1.0 + sw), ylim = c(0, nTip + 1),
                  xlab = "", ylab = "", axes = FALSE, ...)
     if (scale.bar) axis(side = 1, at = seq(0, 1.0, length.out = length(label)),
                         labels = label)
   }
   if (direction == "leftwards") {
-#    plot.window(xlim = c(0 - sw, 1.0), ylim = c(0, nTip + 1))
     plot.default(0, type = "n", xlim = c(0 - sw, 1.0), ylim = c(0, nTip + 1),
                  xlab = "", ylab = "", axes = FALSE, ...)
     if (scale.bar) axis(side = 1, at = seq(0, 1.0, length.out = length(label)),
                         labels = rev(label))
   }
   if (direction == "downwards") {
-#    plot.window(xlim = c(0, nTip + 1), ylim = c(0 - sw, 1.0))
     plot.default(0, type = "n", xlim = c(0, nTip + 1), ylim = c(0 - sw, 1.0),
                  xlab = "", ylab = "", axes = FALSE, ...)
     if (scale.bar) axis(side = 2, at = seq(0, 1.0, length.out = length(label)),
                         labels = rev(label))
   }
   if (direction == "upwards") {
-#    plot.window(xlim = c(0, nTip + 1), ylim = c(0, 1.0 + sw))
     plot.default(0, type = "n", xlim = c(0, nTip + 1), ylim = c(0, 1.0 + sw),
                  xlab = "", ylab = "", axes = FALSE, ...)
     if (scale.bar) axis(side = 2, at = seq(0, 1.0, length.out = length(label)),
